@@ -32,8 +32,7 @@ console = Console()
 def version_callback(print_version: bool) -> None:
     """Print the version of the package."""
     if print_version:
-        console.print(
-            f"[yellow]notion_renderer[/] version: [bold blue]{version}[/]")
+        console.print(f"[yellow]notion_renderer[/] version: [bold blue]{version}[/]")
         raise typer.Exit()
 
 
